Index: /trunk/MagicSoft/Mars/mcalib/MCalibrationChargeCalc.cc
===================================================================
--- /trunk/MagicSoft/Mars/mcalib/MCalibrationChargeCalc.cc	(revision 3450)
+++ /trunk/MagicSoft/Mars/mcalib/MCalibrationChargeCalc.cc	(revision 3451)
@@ -440,5 +440,5 @@
       pix.CheckTimeValidity(&bad);
       
-      if (!bad.IsCalibrationSignalOK())
+      if (bad.IsUnsuitableRun())
         continue;
 
@@ -446,8 +446,10 @@
 
       if (!pix.CalcReducedSigma())
+        {
+          bad.SetUnsuitableRun();
 	  continue;
-
+        }
+      
       pix.CalcFFactorMethod();
-
     }
 
@@ -459,6 +461,9 @@
   if (nvalid == 0)
   {
-      *fLog << err << GetDescriptor() << ": Dear Michele! All pixels have non-valid calibration. " 
-	    << "Did you forget to fill the histograms (filling MHCalibrationChargeCam from MExtractedSignalCam using MFillH) ? " << endl;
+      *fLog << err << GetDescriptor() << ": All pixels have non-valid calibration. " 
+	    << "Did you forget to fill the histograms "
+            << "(filling MHCalibrationChargeCam from MExtractedSignalCam using MFillH) ? " << endl;
+      *fLog << err << GetDescriptor() << ": Or, maybe, you have used a pedestal run " 
+            << "instead of a calibration run " << endl;
     return kFALSE;
   }
@@ -519,5 +524,6 @@
   if (!fBlindPixel->CheckChargeFitValidity())
   {
-      *fLog << warn << "Could not calculate the flux of photons from the PIN Diode, charge fit not valid " << endl;
+      *fLog << warn << "Could not calculate the flux of photons from the Blind Pixel, "
+            << "charge fit not valid " << endl;
       fCam->SetBlindPixelMethodValid(kFALSE);
   }
@@ -526,5 +532,6 @@
       if (!fBlindPixel->CalcFluxInsidePlexiglass())
       {
-	  *fLog << warn << "Could not calculate the flux of photons from the PIN Diode, will skip PIN Diode Calibration " << endl;
+	  *fLog << warn << "Could not calculate the flux of photons from the Blind Pixel, "
+                << "will skip PIN Diode Calibration " << endl;
 	  fCam->SetBlindPixelMethodValid(kFALSE);
       }
@@ -538,5 +545,6 @@
   if (!fPINDiode->CheckChargeFitValidity() || !fPINDiode->CheckTimeFitValidity())
   {
-      *fLog << warn << "Could not calculate the flux of photons from the PIN Diode, charge fit not valid " << endl;
+      *fLog << warn << "Could not calculate the flux of photons from the PIN Diode, "
+            << "charge fit not valid " << endl;
       fCam->SetPINDiodeMethodValid(kFALSE);
   }
@@ -545,5 +553,6 @@
       if (!fPINDiode->CalcFluxOutsidePlexiglass())
       {
-	  *fLog << warn << "Could not calculate the flux of photons from the PIN Diode, will skip PIN Diode Calibration " << endl;
+	  *fLog << warn << "Could not calculate the flux of photons from the PIN Diode, "
+                << "will skip PIN Diode Calibration " << endl;
 	  fCam->SetPINDiodeMethodValid(kFALSE);
       }
